@@ -12,11 +12,11 @@
 #'   determine the hostname for the Droplet in its internal configuration.
 #'   Default: picks a random name from \code{\link{words}} if none supplied.
 #' @param size (character) Size slug identifier. See \code{\link{sizes}()} for
-#'   a complete list. Default: 512mb, the smallest
+#'   a complete list. Default: s-1vcpu-1gb, the smallest
 #' @param image (character/numeric) The image ID of a public or private image,
 #'   or the unique slug identifier for a public image. This image will be the
 #'   base image for your droplet. See \code{\link{images}()} for a complete
-#'   list. Default: ubuntu-14-04-x64
+#'   list. Default: ubuntu-18-04-x64
 #' @param region (character) The unique slug identifier for the region that you
 #'   wish to deploy in. See \code{\link{regions}()} for a complete list.
 #'   Default: sfo1
@@ -60,6 +60,7 @@
 #' @details Note that if you exit the R session or kill the function call
 #' after it's in waiting process (the string of ...), the droplet creation
 #' will continue.
+#' @template dropid
 #'
 #' @return A droplet object
 #'
@@ -82,8 +83,8 @@
 #' summary(d)
 #' }
 droplet_create <- function(name = random_name(),
-                        size = getOption("do_size", "512mb"),
-                        image = getOption("do_image", "ubuntu-14-04-x64"),
+                        size = getOption("do_size", "s-1vcpu-1gb"),
+                        image = getOption("do_image", "ubuntu-18-04-x64"),
                         region = getOption("do_region", "sfo1"),
                         ssh_keys = getOption("do_ssh_keys", NULL),
                         backups = getOption("do_backups", NULL),
@@ -239,6 +240,7 @@ droplet_delete <- function(droplet = NULL, tag = NULL, ...) {
 #' \item{enable_private_networking}{Enable private networking on an existing
 #'   droplet (within a region that has private networking available)}
 #' \item{disable_backups}{Disables backups for a droplet.}
+#' \item{enable_backups}{Enables backups for a droplet.}
 #' \item{power_on}{Turn on a droplet that's turned off.}
 #' }
 #' @inheritParams droplet_delete
