@@ -43,11 +43,13 @@ as.droplet.action <- function(x) {
 #' @export
 print.droplet <- function(x, ...) {
   cat("<droplet>", x$name, " (", x$id, ")\n", sep = "")
-  cat("  IP:     ", droplet_ip_safe(x), "\n", sep = "")
-  cat("  Status: ", x$status, "\n", sep = "")
-  cat("  Region: ", x$region$name, "\n", sep = "")
-  cat("  Image:  ", x$image$name, "\n", sep = "")
-  cat("  Size:   ", x$size_slug, "\n", sep = "")
+  cat("  IP:        ", droplet_ip_safe(x), "\n", sep = "")
+  cat("  Status:    ", x$status, "\n", sep = "")
+  cat("  Region:    ", x$region$name, "\n", sep = "")
+  cat("  Image:     ", x$image$name, "\n", sep = "")
+  cat("  Size:      ", x$size_slug, "\n", sep = "")
+  cat("  Volumes:   ", paste0(unlist(x$volume_ids), collapse = ", "),
+      "\n", sep = "")
 }
 
 #' @export
@@ -73,6 +75,7 @@ summary.droplet <- function(object, ...) {
   cat("  Kernel: ", make_list(list(object$kernel)), "\n")
   cat("  Snapshots: ", unlist(object$snapshot_ids), "\n")
   cat("  Backups: ", unlist(object$backup_ids), "\n")
+  cat("  Tags: ", paste0(unlist(object$tags), collapse = ", "), "\n")
 }
 
 make_list <- function(y){
